@@ -23,7 +23,9 @@ _TransactionNode = namedtuple('_TransactionNode',
         'parameter_groups', 'guid', 'rum_trace', 'cpu_time',
         'suppress_transaction_trace', 'client_cross_process_id',
         'referring_transaction_guid', 'record_tt', 'synthetics_resource_id',
-        'synthetics_job_id', 'synthetics_monitor_id', 'synthetics_header'])
+        'synthetics_job_id', 'synthetics_monitor_id', 'synthetics_header',
+        'is_part_of_cat', 'trip_id', 'path_hash', 'referring_path_hash',
+        'alternate_path_hashes'])
 
 class TransactionNode(_TransactionNode):
 
@@ -315,3 +317,21 @@ class TransactionNode(_TransactionNode):
     def slow_sql_nodes(self, stats):
         for item in self.slow_sql:
             yield item.slow_sql_node(stats, self)
+
+    def apdex_perf_zone(self):
+        """Return the single letter representation of an apdex perf zone."""
+
+        # Apdex is only valid for WebTransactions.
+
+        if self.type != 'WebTransaction':
+            return None
+
+        if self.errors:
+            return 'F'
+        else:
+            if self.duration <= self.apdex_t:
+                return 'S'
+            elif self.duration <= 4 * self.apdex_t:
+                return 'T'
+            else:
+                return 'F'
